@@ -9,7 +9,9 @@
 #include <avogadro/core/cube.h>
 #include <avogadro/core/elements.h>
 #include <avogadro/core/gaussianset.h>
+#include <avogadro/core/layermanager.h>
 #include <avogadro/core/molecule.h>
+#include <avogadro/core/residue.h>
 #include <avogadro/core/unitcell.h>
 #include <avogadro/core/utilities.h>
 
@@ -34,8 +36,11 @@ using Core::CrystalTools;
 using Core::Cube;
 using Core::Elements;
 using Core::GaussianSet;
+using Core::LayerData;
+using Core::LayerManager;
 using Core::lexicalCast;
 using Core::Molecule;
+using Core::Residue;
 using Core::split;
 using Core::Variant;
 
@@ -138,6 +143,15 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  // todo? 2d position
+  // labels
+  json labels = atoms["labels"];
+  if (labels.is_array() && labels.size() == atomCount) {
+    for (size_t i = 0; i < atomCount; ++i) {
+      molecule.atom(i).setLabel(labels[i]);
+    }
+  }
+
   // Check for coordinate sets, and read them in if found, e.g. trajectories.
   json coordSets = atoms["coords"]["3dSets"];
   if (coordSets.is_array() && coordSets.size()) {
@@ -156,6 +170,15 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     molecule.setCoordinate3d(0);
   }
 
+  // Read in colors if they are present.
+  json colors = atoms["colors"];
+  if (colors.is_array() && colors.size() == 3 * atomCount) {
+    for (Index i = 0; i < atomCount; ++i) {
+      Vector3ub color(colors[3 * i], colors[3 * i + 1], colors[3 * i + 2]);
+      molecule.setColor(i, color);
+    }
+  }
+
   // Selection is optional, but if present should be loaded.
   json selection = atoms["selected"];
   if (isBooleanArray(selection) && selection.size() == atomCount)
@@ -164,6 +187,18 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   else if (isNumericArray(selection) && selection.size() == atomCount)
     for (Index i = 0; i < atomCount; ++i)
       molecule.setAtomSelected(i, selection[i] != 0);
+  if (atoms.find("layer") != atoms.end()) {
+    json layerJson = atoms["layer"];
+    if (isNumericArray(layerJson)) {
+      auto& layer = LayerManager::getMoleculeInfo(&molecule)->layer;
+      for (Index i = 0; i < atomCount; ++i) {
+        while (layerJson[i] > layer.maxLayer()) {
+          layer.addLayer();
+        }
+        layer.addAtom(layerJson[i], i);
+      }
+    }
+  }
 
   // Bonds are optional, but if present should be loaded.
   json bonds = jsonRoot["bonds"];
@@ -182,6 +217,47 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  // residues are optional, but should be loaded
+  json residues = jsonRoot["residues"];
+  if (residues.is_array()) {
+    for (unsigned int i = 0; i < residues.size(); ++i) {
+      json residue = residues[i];
+      if (!residue.is_object())
+        continue; // malformed
+
+      auto name = residue["name"].get<std::string>();
+      auto id = static_cast<Index>(residue["id"]);
+      auto chainId = residue["chainId"].get<char>();
+      Residue newResidue(name, id, chainId);
+
+      json hetero = residue["hetero"];
+      if (hetero == true)
+        newResidue.setHeterogen(true);
+
+      int secStruct = residue.value("secStruct", -1);
+      if (secStruct != -1)
+        newResidue.setSecondaryStructure(
+          static_cast<Avogadro::Core::Residue::SecondaryStructure>(secStruct));
+
+      json atomsResidue = residue["atoms"];
+      if (atomsResidue.is_object()) {
+        for (auto& item : atomsResidue.items()) {
+          if (item.value() < molecule.atomCount()) {
+            const Atom& atom = molecule.atom(item.value());
+            newResidue.addResidueAtom(item.key(), atom);
+          }
+        }
+      }
+      json color = residue["color"];
+      if (color.is_array() && color.size() == 3) {
+        Vector3ub col = Vector3ub(color[0], color[1], color[2]);
+        newResidue.setColor(col);
+      }
+
+      molecule.addResidue(newResidue);
+    }
+  }
+
   json unitCell = jsonRoot["unitCell"];
   if (!unitCell.is_object())
     unitCell = jsonRoot["unit cell"];
@@ -384,6 +460,38 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  if (jsonRoot.find("layer") != jsonRoot.end()) {
+    auto names = LayerManager::getMoleculeInfo(&molecule);
+    json visible = jsonRoot["layer"]["visible"];
+    if (isBooleanArray(visible)) {
+      for (const auto& v : visible) {
+        names->visible.push_back(v);
+      }
+    }
+    json locked = jsonRoot["layer"]["locked"];
+    if (isBooleanArray(locked)) {
+      for (const auto& l : locked) {
+        names->locked.push_back(l);
+      }
+    }
+
+    json enables = jsonRoot["layer"]["enable"];
+    for (const auto& enable : enables.items()) {
+      names->enable[enable.key()] = std::vector<bool>();
+      for (const auto& e : enable.value()) {
+        names->enable[enable.key()].push_back(e);
+      }
+    }
+
+    json settings = jsonRoot["layer"]["settings"];
+    for (const auto& setting : settings.items()) {
+      names->settings[setting.key()] = Core::Array<LayerData*>();
+      for (const auto& s : setting.value()) {
+        names->settings[setting.key()].push_back(new LayerData(s));
+      }
+    }
+  }
+
   return true;
 }
 
@@ -474,7 +582,6 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
 
       auto atomIndices = gaussian->atomIndices();
       json shellToAtomMap;
-      std::cout << "atomIndices " << atomIndices.size() << std::endl;
       for (size_t i = 0; i < atomIndices.size(); ++i)
         shellToAtomMap.push_back(atomIndices[i]);
       basis["shellToAtomMap"] = shellToAtomMap;
@@ -576,12 +683,24 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
   if (molecule.atomCount()) {
     json elements;
     json selected;
+    json colors;
+
+    Vector3ub color;
+    bool hasCustomColors = molecule.colors().size() == molecule.atomCount();
     for (Index i = 0; i < molecule.atomCount(); ++i) {
       elements.push_back(molecule.atom(i).atomicNumber());
       selected.push_back(molecule.atomSelected(i));
+
+      color = molecule.color(i);
+      colors.push_back(color.x());
+      colors.push_back(color.y());
+      colors.push_back(color.z());
     }
     root["atoms"]["elements"]["number"] = elements;
-    root["atoms"]["selected"] = selected;
+    if (!molecule.isSelectionEmpty())
+      root["atoms"]["selected"] = selected;
+    if (hasCustomColors)
+      root["atoms"]["colors"] = colors;
 
     // 3d positions:
     if (molecule.atomPositions3d().size() == molecule.atomCount()) {
@@ -628,6 +747,22 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     }
   }
 
+  // labels
+  json labels;
+  for (size_t i = 0; i < molecule.atomCount(); ++i) {
+    labels.push_back(molecule.label(i));
+  }
+  root["atoms"]["labels"] = labels;
+
+  auto layer = LayerManager::getMoleculeInfo(&molecule)->layer;
+  if (layer.atomCount()) {
+    json atomLayer;
+    for (Index i = 0; i < layer.atomCount(); ++i) {
+      atomLayer.push_back(layer.getLayerID(i));
+    }
+    root["atoms"]["layer"] = atomLayer;
+  }
+
   // Create and populate the bond arrays.
   if (molecule.bondCount()) {
     json connections;
@@ -642,6 +777,35 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     root["bonds"]["order"] = order;
   }
 
+  // Create and populate any residue arrays
+  if (molecule.residues().size() > 0) {
+    json residues; // array of objects
+    for (auto residue : molecule.residues()) {
+      json entry;
+      entry["name"] = residue.residueName();
+      entry["id"] = residue.residueId();
+      entry["chainId"] = residue.chainId();
+      entry["secStruct"] = residue.secondaryStructure();
+      if (residue.isHeterogen())
+        entry["hetero"] = true;
+
+      json color;
+      color.push_back(residue.color()[0]);
+      color.push_back(residue.color()[1]);
+      color.push_back(residue.color()[2]);
+      entry["color"] = color;
+
+      json atoms;
+      for (auto item : residue.atomNameMap()) {
+        // dictionary between names and atom Id
+        atoms[item.first] = item.second.index();
+      }
+      entry["atoms"] = atoms;
+      residues.push_back(entry);
+    }
+    root["residues"] = residues;
+  }
+
   // If there is vibrational data write this out too.
   if (molecule.vibrationFrequencies().size() > 0) {
     // A few sanity checks before we begin.
@@ -671,6 +835,33 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     root["vibrations"]["eigenVectors"] = eigenVectors;
   }
 
+  auto names = LayerManager::getMoleculeInfo(&molecule);
+  json visible;
+  for (const bool v : names->visible) {
+    visible.push_back(v);
+  }
+  root["layer"]["visible"] = visible;
+  json locked;
+  for (const bool l : names->locked) {
+    locked.push_back(l);
+  }
+  root["layer"]["locked"] = locked;
+  for (const auto& enables : names->enable) {
+    json enable;
+    for (const bool e : enables.second) {
+      enable.push_back(e);
+    }
+    root["layer"]["enable"][enables.first] = enable;
+  }
+
+  for (const auto& settings : names->settings) {
+    json setting;
+    for (const auto& e : settings.second) {
+      setting.push_back(e->serialize());
+    }
+    root["layer"]["settings"][settings.first] = setting;
+  }
+
   // Write out the file, use a two space indent to "pretty print".
   file << std::setw(2) << root;
 
