@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_BALLANDSTICK_H
@@ -31,15 +20,12 @@ class BallAndStick : public QtGui::ScenePlugin
   Q_OBJECT
 
 public:
-  explicit BallAndStick(QObject* parent = 0);
+  explicit BallAndStick(QObject* parent = nullptr);
   ~BallAndStick() override;
 
-  void process(const Core::Molecule& molecule,
+  void process(const QtGui::Molecule& molecule,
                Rendering::GroupNode& node) override;
 
-  void processEditable(const QtGui::RWMolecule& molecule,
-                       Rendering::GroupNode& node) override;
-
   QString name() const override { return tr("Ball and Stick"); }
 
   QString description() const override
@@ -47,24 +33,21 @@ public:
     return tr("Render atoms as spheres and bonds as cylinders.");
   }
 
-  bool isEnabled() const override;
-
-  void setEnabled(bool enable) override;
-
   QWidget* setupWidget() override;
 
-private slots:
+  static std::string getName() { return "Ball and Stick"; }
+
+public slots:
+  void atomRadiusChanged(int value);
+  void bondRadiusChanged(int value);
   void multiBonds(bool show);
   void showHydrogens(bool show);
 
 private:
-  bool m_enabled;
-
   Rendering::GroupNode* m_group;
-
-  QWidget* m_setupWidget;
-  bool m_multiBonds;
-  bool m_showHydrogens;
+  std::string m_name = getName();
+  float m_atomScale = 0.3f;
+  float m_bondRadius = 0.1f;
 };
 
 } // end namespace QtPlugins
