@@ -38,7 +38,7 @@ class CoordinateEditorDialog : public QDialog
 {
   Q_OBJECT
 public:
-  explicit CoordinateEditorDialog(QWidget* parent_ = 0);
+  explicit CoordinateEditorDialog(QWidget* parent_ = nullptr);
   ~CoordinateEditorDialog() override;
 
   void setMolecule(QtGui::Molecule* mol);
