@@ -37,11 +37,11 @@ namespace QtPlugins {
 using Avogadro::MoleQueue::JobObject;
 
 Cp2kInput::Cp2kInput(QObject* parent_)
-  : ExtensionPlugin(parent_), m_action(new QAction(this)), m_molecule(NULL),
-    m_dialog(NULL), m_outputFormat(NULL)
+  : ExtensionPlugin(parent_), m_action(new QAction(this)), m_molecule(nullptr),
+    m_dialog(nullptr), m_outputFormat(nullptr)
 {
   m_action->setEnabled(true);
-  m_action->setText(tr("&CP2K"));
+  m_action->setText(tr("&CP2K..."));
   connect(m_action, SIGNAL(triggered()), SLOT(menuActivated()));
 }
 
@@ -70,7 +70,7 @@ void Cp2kInput::setMolecule(QtGui::Molecule* mol)
 
 void Cp2kInput::openJobOutput(const JobObject& job)
 {
-  m_outputFormat = NULL;
+  m_outputFormat = nullptr;
   m_outputFileName.clear();
 
   QString outputPath(job.value("outputDirectory").toString());
@@ -79,7 +79,7 @@ void Cp2kInput::openJobOutput(const JobObject& job)
   FileFormatDialog::FormatFilePair result = FileFormatDialog::fileToRead(
     qobject_cast<QWidget*>(parent()), tr("Open Output File"), outputPath);
 
-  if (result.first == NULL) // User canceled
+  if (result.first == nullptr) // User canceled
     return;
 
   m_outputFormat = result.first;
@@ -99,7 +99,7 @@ bool Cp2kInput::readMolecule(QtGui::Molecule& mol)
                                .arg(QString::fromStdString(reader->error())));
   }
 
-  m_outputFormat = NULL;
+  m_outputFormat = nullptr;
   m_outputFileName.clear();
 
   return success;
