@@ -43,7 +43,7 @@ class Cp2kInputDialog : public QDialog
   Q_OBJECT
 
 public:
-  explicit Cp2kInputDialog(QWidget* parent_ = 0, Qt::WindowFlags f = 0);
+  explicit Cp2kInputDialog(QWidget* parent_ = nullptr, Qt::WindowFlags f = 0);
   ~Cp2kInputDialog();
 
   void setMolecule(QtGui::Molecule* mol);
