@@ -42,7 +42,7 @@ class SupercellDialog : public QDialog
 {
   Q_OBJECT
 public:
-  SupercellDialog(QWidget* p = 0);
+  SupercellDialog(QWidget* p = nullptr);
   ~SupercellDialog() override;
 
   bool buildSupercell(Avogadro::QtGui::Molecule& mol);
