@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012-13 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "editor.h"
@@ -80,7 +69,7 @@ Editor::Editor(QObject* parent_)
     m_toolWidget(new EditorToolWidget(qobject_cast<QWidget*>(parent_))),
     m_pressedButtons(Qt::NoButton),
     m_clickedAtomicNumber(INVALID_ATOMIC_NUMBER), m_bondAdded(false),
-    m_fixValenceLater(false)
+    m_fixValenceLater(false), m_layerManager("Editor")
 {
   m_activateAction->setText(tr("Draw"));
   m_activateAction->setIcon(QIcon(":/icons/editor.png"));
@@ -105,7 +94,10 @@ QUndoCommand* Editor::mousePressEvent(QMouseEvent* e)
 
   if (m_pressedButtons & Qt::LeftButton) {
     m_clickedObject = m_renderer->hit(e->pos().x(), e->pos().y());
-
+    if (m_layerManager.activeLayerLocked()) {
+      e->accept();
+      return nullptr;
+    }
     switch (m_clickedObject.type) {
       case Rendering::InvalidType:
         m_molecule->beginMergeMode(tr("Draw Atom"));
@@ -146,7 +138,10 @@ QUndoCommand* Editor::mouseReleaseEvent(QMouseEvent* e)
 {
   if (!m_renderer || !m_molecule)
     return nullptr;
-
+  if (m_layerManager.activeLayerLocked()) {
+    e->accept();
+    return nullptr;
+  }
   updatePressedButtons(e, true);
 
   if (m_clickedObject.type == Rendering::InvalidType)
@@ -175,10 +170,14 @@ QUndoCommand* Editor::mouseMoveEvent(QMouseEvent* e)
 {
   if (!m_renderer)
     return nullptr;
-
   if (m_pressedButtons & Qt::LeftButton)
-    if (m_clickedObject.type == Rendering::AtomType)
+    if (m_clickedObject.type == Rendering::AtomType) {
+      if (m_layerManager.activeLayerLocked()) {
+        e->accept();
+        return nullptr;
+      }
       atomLeftDrag(e);
+    }
 
   return nullptr;
 }
@@ -187,9 +186,11 @@ QUndoCommand* Editor::keyPressEvent(QKeyEvent* e)
 {
   if (e->text().isEmpty())
     return nullptr;
-
   e->accept();
 
+  if (m_layerManager.activeLayerLocked()) {
+    return nullptr;
+  }
   // Set a timer to clear the buffer on first keypress:
   if (m_keyPressBuffer.isEmpty())
     QTimer::singleShot(2000, this, SLOT(clearKeyPressBuffer()));
@@ -231,7 +232,9 @@ void Editor::draw(Rendering::GroupNode& node)
   QString distanceLabel = tr("Distance:");
   int labelWidth = -1 * distanceLabel.size();
 
-  QString overlayText = tr("Distance: %L1 Å").arg(m_bondDistance, 10, 'f', 3);
+  QString overlayText = tr("%1 %L2")
+                          .arg(distanceLabel, labelWidth)
+                          .arg(tr("%L1 Å").arg(m_bondDistance, 9, 'f', 3), 9);
 
   TextProperties overlayTProp;
   overlayTProp.setFontFamily(TextProperties::Mono);
@@ -410,7 +413,7 @@ void Editor::atomLeftDrag(QMouseEvent* e)
   Molecule::MoleculeChanges changes = Molecule::NoChange;
 
   // Get the list of hits at the current mouse position:
-  std::multimap<float, Identifier> hits =
+  const std::multimap<float, Identifier> hits =
     m_renderer->hits(e->pos().x(), e->pos().y());
 
   // Check if the previously clicked atom is still under the mouse.
@@ -502,8 +505,8 @@ void Editor::atomLeftDrag(QMouseEvent* e)
 
   if (atomToBond.isValid()) {
     // If we have a newAtom, destroy it
-    if (m_newObject.type == Rendering::AtomType) {
-
+    if (m_newObject.isValid() && atomToBond.index != m_newObject.index &&
+        m_newObject.type == Rendering::AtomType) {
       m_molecule->removeAtom(m_newObject.index);
       changes |= Molecule::Atoms | Molecule::Bonds | Molecule::Removed;
       m_newObject = Identifier();
@@ -512,10 +515,13 @@ void Editor::atomLeftDrag(QMouseEvent* e)
     // Skip the rest of this block if atomToBond is already bonded
     if (m_bondedAtom != atomToBond) {
       // If the currently bonded atom exists, break the bond
-      if (m_bondedAtom.isValid()) {
+      if (m_bondedAtom.isValid() && m_clickedObject.isValid() &&
+          m_bondedAtom.index < m_molecule->atomCount() &&
+          m_clickedObject.index < m_molecule->atomCount() &&
+          m_molecule->bond(m_bondedAtom.index, m_clickedObject.index)
+            .isValid()) {
         if (m_molecule->removeBond(m_molecule->atom(m_bondedAtom.index),
                                    m_molecule->atom(m_clickedObject.index))) {
-          ;
           changes |= Molecule::Bonds | Molecule::Removed;
         }
         m_bondedAtom = Identifier();
@@ -525,6 +531,7 @@ void Editor::atomLeftDrag(QMouseEvent* e)
       RWAtom clickedAtom = m_molecule->atom(m_clickedObject.index);
       RWAtom bondedAtom = m_molecule->atom(atomToBond.index);
       if (!m_molecule->bond(clickedAtom, bondedAtom).isValid()) {
+
         int bondOrder = m_toolWidget->bondOrder();
         if (bondOrder == 0) {
           // automatic - guess the size
@@ -547,7 +554,6 @@ void Editor::atomLeftDrag(QMouseEvent* e)
       m_bondedAtom = atomToBond;
       changes |= Molecule::Bonds | Molecule::Added;
     }
-
     m_molecule->emitChanged(changes);
     return;
   }
@@ -560,7 +566,8 @@ void Editor::atomLeftDrag(QMouseEvent* e)
   if (!m_newObject.isValid()) {
     // Add a new atom bonded to the clicked atom
     RWAtom clickedAtom = m_molecule->atom(m_clickedObject.index);
-    newAtom = m_molecule->addAtom(m_toolWidget->atomicNumber());
+    newAtom = m_molecule->addAtom(m_toolWidget->atomicNumber(),
+                                  clickedAtom.position3d());
 
     // Handle the automatic bond order
     int bondOrder = m_toolWidget->bondOrder();
