@@ -30,7 +30,7 @@ class Force : public QtGui::ScenePlugin
   Q_OBJECT
 
 public:
-  explicit Force(QObject* parent = 0);
+  explicit Force(QObject* parent = nullptr);
   ~Force() override;
 
   void process(const Core::Molecule& molecule,
@@ -46,6 +46,8 @@ public:
 
   bool isEnabled() const override;
 
+  bool isActiveLayerEnabled() const override;
+
   void setEnabled(bool enable) override;
 
 private:
