@@ -1,21 +1,11 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
 
-  Copyright 2013 Kitware, Inc.
-
   Adapted from Avogadro 1.x with the following authors' permission:
   Copyright 2007 Donald Ephraim Curtis
   Copyright 2008 Marcus D. Hanwell
 
   This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
 ******************************************************************************/
 
 #include "measuretool.h"
@@ -36,6 +26,8 @@
 #include <avogadro/qtgui/molecule.h>
 #include <avogadro/qtgui/rwmolecule.h>
 
+#include <avogadro/core/angletools.h>
+
 #include <QtGui/QGuiApplication>
 #include <QtGui/QIcon>
 #include <QtGui/QMouseEvent>
@@ -145,7 +137,7 @@ void MeasureTool::createLabels(T* mol, GeometryNode* geo,
     label->setTextProperties(atomLabelProp);
     label->setAnchor(positions[i].cast<float>());
     label->setRadius(
-      static_cast<float>(Elements::radiusCovalent(atomicNumber)));
+      static_cast<float>(Elements::radiusCovalent(atomicNumber)) + 0.1f);
     geo->addDrawable(label);
   }
 }
@@ -202,32 +194,28 @@ void MeasureTool::draw(Rendering::GroupNode& node)
       overlayText +=
         QString("%1 %L2\n")
           .arg(tr("Dihedral:"), labelWidth)
-          .arg(tr("%L1°").arg(dihedralAngle(v1, v2, v3), 10, 'f', 3), 10);
-      angle23 =
-        static_cast<float>(std::acos((-v2).dot(v3) / (v2Norm * v3Norm))) *
-        RAD_TO_DEG_F;
+          .arg(tr("%L1°").arg(dihedralAngle(v1, v2, v3), 9, 'f', 3), 9);
+      angle23 = bondAngle(v2, v3);
     // fall through
     case 3:
-      angle12 =
-        static_cast<float>(std::acos((-v1).dot(v2) / (v1Norm * v2Norm))) *
-        RAD_TO_DEG_F;
+      angle12 = bondAngle(v1, v2);
       overlayText +=
         QString("%1 %L2 %L3\n")
           .arg(tr("Angles:"), labelWidth)
-          .arg(tr("%L1°").arg(angle12, 10, 'f', 3), 10)
-          .arg(angle23 < 360.f ? tr("%L1°").arg(angle23, 10, 'f', 3)
+          .arg(tr("%L1°").arg(angle12, 9, 'f', 3), 9)
+          .arg(angle23 < 360.f ? tr("%L1°").arg(angle23, 9, 'f', 3)
                                : QString(),
                10);
     // fall through
     case 2:
       overlayText +=
-        QString("%1 %L2 %L3 %L4")
+        QString("%1 %L2%L3%L4")
           .arg(tr("Distance:"), labelWidth)
-          .arg(tr("%L1 Å").arg(v1Norm, 10, 'f', 3), 10)
-          .arg(v2Norm >= 0.f ? tr("%L1 Å").arg(v2Norm, 10, 'f', 3) : QString(),
-               10)
-          .arg(v3Norm >= 0.f ? tr("%L1 Å").arg(v3Norm, 10, 'f', 3) : QString(),
-               10);
+          .arg(tr("%L1 Å").arg(v1Norm, 9, 'f', 3), 9)
+          .arg(v2Norm >= 0.f ? tr("%L1 Å").arg(v2Norm, 9, 'f', 3) : QString(),
+               9)
+          .arg(v3Norm >= 0.f ? tr("%L1 Å").arg(v3Norm, 9, 'f', 3) : QString(),
+               9);
     default:
       break;
   }
@@ -271,20 +259,6 @@ inline Vector3ub MeasureTool::contrastingColor(const Vector3ub& rgb) const
   return result;
 }
 
-float MeasureTool::dihedralAngle(const Vector3& b1, const Vector3& b2,
-                                 const Vector3& b3) const
-{
-  // See http://math.stackexchange.com/questions/47059/
-  // how-do-i-calculate-a-dihedral-angle-given-cartesian-coordinates
-  // for description of algorithm
-  const Vector3 n1 = b1.cross(b2).normalized();
-  const Vector3 n2 = b2.cross(b3).normalized();
-  const Vector3 m1 = n1.cross(b2.normalized());
-  const Real x(n1.dot(n2));
-  const Real y(m1.dot(n2));
-  return static_cast<float>(std::atan2(y, x)) * RAD_TO_DEG_F;
-}
-
 bool MeasureTool::toggleAtom(const Rendering::Identifier& atom)
 {
   int ind = m_atoms.indexOf(atom);
