@@ -38,7 +38,7 @@ OpenMMInput::OpenMMInput(QObject* parent_)
     m_dialog(nullptr), m_outputFormat(nullptr)
 {
   m_action->setEnabled(true);
-  m_action->setText(tr("&OpenMM Script Builder"));
+  m_action->setText(tr("&OpenMM Script..."));
   connect(m_action, SIGNAL(triggered()), SLOT(menuActivated()));
 }
 
