@@ -321,7 +321,7 @@ void PlayerTool::recordMovie()
   } else if (selfFilter == tr("Movie (*.avi)")) {
     gwavi_t* gwavi;
     gwavi = gwavi_open((baseName + ".avi").toLatin1().data(), EXPORT_WIDTH,
-                       EXPORT_HEIGHT, "MJPG", m_animationFPS->value(), NULL);
+                       EXPORT_HEIGHT, "MJPG", m_animationFPS->value(), nullptr);
     for (int i = 0; i < m_molecule->coordinate3dCount(); ++i) {
       m_molecule->setCoordinate3d(i);
       if (bonding) {
