@@ -34,14 +34,20 @@
 #include <avogadro/core/atom.h>
 #include <avogadro/core/vector.h>
 #include <avogadro/qtgui/molecule.h>
+#include <avogadro/qtgui/rwmolecule.h>
 
 #include <QtGui/QIcon>
 #include <QtGui/QMouseEvent>
 #include <QtWidgets/QAction>
 
+#include <queue>
+#include <set>
+
 using Avogadro::Core::Array;
 using Avogadro::Core::Atom;
 using Avogadro::QtGui::Molecule;
+using Avogadro::QtGui::PluginLayerManager;
+using Avogadro::QtGui::RWMolecule;
 using Avogadro::Rendering::GeometryNode;
 using Avogadro::Rendering::GroupNode;
 using Avogadro::Rendering::Identifier;
@@ -54,13 +60,15 @@ SelectionTool::SelectionTool(QObject* parent_)
   : QtGui::ToolPlugin(parent_), m_activateAction(new QAction(this)),
     m_molecule(nullptr), m_renderer(nullptr),
     m_toolWidget(new SelectionToolWidget(qobject_cast<QWidget*>(parent_))),
-    m_drawSelectionBox(false)
+    m_drawSelectionBox(false), m_doubleClick(false), m_initSelectionBox(false),
+    m_layerManager("Selection Tool")
 {
   m_activateAction->setText(tr("Selection"));
   m_activateAction->setIcon(QIcon(":/icons/selectiontool.png"));
 
   connect(m_toolWidget, SIGNAL(colorApplied(Vector3ub)), this,
           SLOT(applyColor(Vector3ub)));
+  connect(m_toolWidget, SIGNAL(changeLayer(int)), this, SLOT(applyLayer(int)));
 }
 
 SelectionTool::~SelectionTool() {}
@@ -72,55 +80,45 @@ QWidget* SelectionTool::toolWidget() const
 
 QUndoCommand* SelectionTool::mousePressEvent(QMouseEvent* e)
 {
-  if (e->button() != Qt::LeftButton || !m_renderer)
+  if (e->button() != Qt::LeftButton || !m_renderer) {
+    m_initSelectionBox = false;
     return nullptr;
+  }
 
   m_drawSelectionBox = false;
+  m_initSelectionBox = true;
   m_start = Vector2(e->pos().x(), e->pos().y());
   m_end = m_start;
-  Identifier hit = m_renderer->hit(e->pos().x(), e->pos().y());
-
-  // If an atom is clicked, accept the event, but don't add it to the atom list
-  // until the button is released (this way the user can cancel the click by
-  // moving off the atom, and the click won't get passed to the default tool).
-  if (hit.type == Rendering::AtomType)
-    e->accept();
-
-  // Remove the global accept to prevent the rectangle selection area from being
-  // rendered as the selection code is not yet in place for the scene.
   e->accept();
-
   return nullptr;
 }
 
 QUndoCommand* SelectionTool::mouseReleaseEvent(QMouseEvent* e)
 {
   // If the click is released on an atom, add it to the list
-  if (e->button() != Qt::LeftButton || !m_renderer)
+  if (e->button() != Qt::LeftButton || !m_renderer || m_doubleClick) {
+    m_doubleClick = false;
     return nullptr;
-
+  }
   // Assess whether the selection box is big enough to use, or a mis-click.
-  bool bigEnough = false;
   m_end = Vector2(e->pos().x(), e->pos().y());
-  if (fabs(m_start.x() - m_end.x()) > 2 && fabs(m_start.y() - m_end.y()) > 2)
-    bigEnough = true;
+  Vector2f start(m_start.x() < m_end.x() ? m_start.x() : m_end.x(),
+                 m_start.y() < m_end.y() ? m_start.y() : m_end.y());
+  Vector2f end(m_start.x() > m_end.x() ? m_start.x() : m_end.x(),
+               m_start.y() > m_end.y() ? m_start.y() : m_end.y());
+  bool bigEnough =
+    fabs(start.x() - end.x()) > 2 && fabs(start.y() - end.y()) > 2;
 
+  bool anySelect = false;
+  Index selectedIndex = MaxIndex;
   if (m_drawSelectionBox && bigEnough) {
-    auto hits =
-      m_renderer->hits(m_start.x(), m_start.y(), m_end.x(), m_end.y());
-
-    // Toggle the selection if the Ctrl modifier is pressed.
-    if (e->modifiers() & Qt::ControlModifier) {
-      for (auto it = hits.begin(); it != hits.end(); ++it) {
-        toggleAtom(*it);
-      }
-    } else {
-      // If the shift modifier is not pressed clear the previous selection.
-      if (!(e->modifiers() & Qt::ShiftModifier)) {
-        clearAtoms();
-      }
-      for (auto it = hits.begin(); it != hits.end(); ++it) {
-        addAtom(*it);
+    shouldClean(e);
+    m_initSelectionBox = false;
+    auto hits = m_renderer->hits(start.x(), start.y(), end.x(), end.y());
+    for (const auto& hit : hits) {
+      if (hit.type == Rendering::AtomType) {
+        anySelect = selectAtom(e, hit.index) || anySelect;
+        selectedIndex = hit.index;
       }
     }
   } else {
@@ -128,41 +126,65 @@ QUndoCommand* SelectionTool::mouseReleaseEvent(QMouseEvent* e)
     m_start = Vector2(e->pos().x(), e->pos().y());
     m_end = m_start;
     Identifier hit = m_renderer->hit(e->pos().x(), e->pos().y());
-
     // Now add the atom on release.
     if (hit.type == Rendering::AtomType) {
-      toggleAtom(hit);
+      // store the result in case it's a toggle
+      bool selected = selectAtom(e, hit.index);
+      shouldClean(e);
+      if (selected) {
+        anySelect = addAtom(hit.index);
+        selectedIndex = hit.index;
+      } else {
+        anySelect = removeAtom(hit.index);
+        selectedIndex = hit.index;
+      }
     }
   }
-
+  if (anySelect) {
+    m_toolWidget->setDropDown(m_layerManager.getLayerID(selectedIndex),
+                              m_layerManager.layerCount());
+  }
   m_drawSelectionBox = false;
-
   // Disable this code until rectangle selection is ready.
   emit drawablesChanged();
   e->accept();
-
   return nullptr;
 }
 
 QUndoCommand* SelectionTool::mouseDoubleClickEvent(QMouseEvent* e)
 {
-  // Reset the atom list
   if (e->button() == Qt::LeftButton) {
-    clearAtoms();
-    emit drawablesChanged();
-    e->accept();
+    m_doubleClick = true;
+    m_initSelectionBox = false;
+    Vector2 select = Vector2(e->pos().x(), e->pos().y());
+    Identifier hit = m_renderer->hit(select.x(), select.y());
+    // Reset the atom list
+    if (!hit.isValid()) {
+      clearAtoms();
+    } else {
+      shouldClean(e);
+      m_drawSelectionBox = false;
+      // resync the select from simple click only on control
+      if (e->modifiers() & Qt::ControlModifier) {
+        toggleAtom(hit.index);
+      }
+      selectLinkedMolecule(e, hit.index);
+      emit drawablesChanged();
+      e->accept();
+    }
   }
   return nullptr;
-}
+} // namespace QtPlugins
 
 QUndoCommand* SelectionTool::mouseMoveEvent(QMouseEvent* e)
 {
   // Disable this code until rectangle selection is ready.
-  m_drawSelectionBox = true;
-  m_end = Vector2(e->pos().x(), e->pos().y());
-  emit drawablesChanged();
-
-  e->accept();
+  if (m_initSelectionBox) {
+    m_drawSelectionBox = true;
+    m_end = Vector2(e->pos().x(), e->pos().y());
+    emit drawablesChanged();
+    e->accept();
+  }
   return nullptr;
 }
 
@@ -173,7 +195,7 @@ QUndoCommand* SelectionTool::keyPressEvent(QKeyEvent*)
 
 void SelectionTool::draw(Rendering::GroupNode& node)
 {
-  if (!m_drawSelectionBox) {
+  if (!m_drawSelectionBox || !m_initSelectionBox) {
     node.clear();
     return;
   }
@@ -218,12 +240,40 @@ void SelectionTool::draw(Rendering::GroupNode& node)
 
 void SelectionTool::applyColor(Vector3ub color)
 {
-  for (Index i = 0; i < m_molecule->atomCount(); ++i) {
-    auto a = m_molecule->atom(i);
+  RWMolecule* rwmol = m_molecule->undoMolecule();
+  rwmol->beginMergeMode(tr("Paint Atoms"));
+  for (Index i = 0; i < rwmol->atomCount(); ++i) {
+    auto a = rwmol->atom(i);
     if (a.selected())
       a.setColor(color);
   }
-  m_molecule->emitChanged(Molecule::Atoms);
+  rwmol->endMergeMode();
+  rwmol->emitChanged(Molecule::Atoms | Molecule::Modified);
+}
+
+void SelectionTool::applyLayer(int layer)
+{
+  if (layer < 0) {
+    return;
+  }
+  RWMolecule* rwmol = m_molecule->undoMolecule();
+  rwmol->beginMergeMode(tr("Change Layer"));
+  for (Index i = 0; i < rwmol->atomCount(); ++i) {
+    auto a = rwmol->atom(i);
+    if (a.selected()) {
+      a.setLayer(layer);
+    }
+  }
+  rwmol->endMergeMode();
+  rwmol->emitChanged(Molecule::Atoms | Molecule::Modified);
+}
+
+void SelectionTool::selectLinkedMolecule(QMouseEvent* e, Index atom)
+{
+  auto connectedAtoms = m_molecule->graph().connectedComponent(atom);
+  for (auto a : connectedAtoms) {
+    selectAtom(e, a);
+  }
 }
 
 void SelectionTool::clearAtoms()
@@ -232,23 +282,53 @@ void SelectionTool::clearAtoms()
     m_molecule->atom(i).setSelected(false);
 }
 
-bool SelectionTool::addAtom(const Rendering::Identifier& atom)
+bool SelectionTool::addAtom(const Index& atom)
 {
-  m_molecule->atom(atom.index).setSelected(true);
+  m_molecule->atom(atom).setSelected(true);
   return true;
 }
 
-bool SelectionTool::removeAtom(const Rendering::Identifier& atom)
+bool SelectionTool::removeAtom(const Index& atom)
 {
-  m_molecule->atom(atom.index).setSelected(false);
+  m_molecule->atom(atom).setSelected(false);
   return true;
 }
 
-bool SelectionTool::toggleAtom(const Rendering::Identifier& atom)
+bool SelectionTool::toggleAtom(const Index& atom)
 {
-  Atom a = m_molecule->atom(atom.index);
+  Atom a = m_molecule->atom(atom);
   a.setSelected(!a.selected());
-  return true;
+  return a.selected();
+}
+
+bool SelectionTool::shouldClean(QMouseEvent* e)
+{
+  // acumulate the selection if shift or ctrl are presset
+  if (!(e->modifiers() & Qt::ControlModifier) &&
+      !(e->modifiers() & Qt::ShiftModifier)) {
+    clearAtoms();
+    return true;
+  }
+  return false;
+}
+
+bool SelectionTool::selectAtom(QMouseEvent* e, const Index& index)
+{
+  if (m_layerManager.atomLocked(index)) {
+    return false;
+  }
+  // control toggles the selection
+  if (e->modifiers() & Qt::ControlModifier) {
+    return toggleAtom(index);
+  }
+  // shift and default selection adds
+  else if (e->modifiers() & Qt::ShiftModifier || m_drawSelectionBox) {
+    return addAtom(index);
+  }
+  // default toggle
+  else {
+    return toggleAtom(index);
+  }
 }
 
 } // namespace QtPlugins
