@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_WIREFRAME_H
@@ -30,37 +19,29 @@ class Wireframe : public QtGui::ScenePlugin
   Q_OBJECT
 
 public:
-  explicit Wireframe(QObject* parent = 0);
+  explicit Wireframe(QObject* parent = nullptr);
   ~Wireframe() override;
 
-  void process(const Core::Molecule& molecule,
+  void process(const QtGui::Molecule& molecule,
                Rendering::GroupNode& node) override;
 
-  QString name() const override { return tr("Wireframe"); }
+  QString name() const override { return tr(m_name.c_str()); }
 
   QString description() const override
   {
     return tr("Render the molecule as a wireframe.");
   }
 
-  bool isEnabled() const override;
-
-  void setEnabled(bool enable) override;
-
   QWidget* setupWidget() override;
 
-private slots:
+public slots:
   void multiBonds(bool show);
   void showHydrogens(bool show);
+  void setWidth(double width);
 
 private:
-  bool m_enabled;
-
   Rendering::GroupNode* m_group;
-
-  QWidget* m_setupWidget;
-  bool m_multiBonds;
-  bool m_showHydrogens;
+  std::string m_name = "Wireframe";
 };
 
 } // end namespace QtPlugins
